.. _userdoc-analysis-modules:

Analysis modules
################

This is a list of all analysis modules provided by MAICoS. Note that we do not have an
example section for each module. Instead, we refer to our :ref:`tutorial <usage-python>`
and :ref:`userdoc-how-to`. Once you understand the basic structure taught there, you can
work with all modules. If not, feel free to raise an issue in GitHub_ or ask us on
Discord_.

.. _`GitHub`: https://github.com/maicos-devel/maicos/issues
.. _`Discord`: https://discord.gg/mnrEQWVAed

.. toctree::
   :maxdepth: 1
   :glob:

   ./*
